<?php
/**
 * Limelight functions and definitions
 *
 * @package Limelight
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'limelight_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function limelight_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Limelight, use a find and replace
	 * to change 'limelight' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'limelight', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 200, null, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'limelight' ),
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'limelight_custom_background_args', array(
		'default-color' => 'F1F1F1',
		'default-image' => '',
	) ) );
}
endif; // limelight_setup
add_action( 'after_setup_theme', 'limelight_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function limelight_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'limelight' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Home Box 1', 'limelight' ),
		'id'            => 'home-box-1',
		'before_widget' => '<div class="home-box-inner">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="home-box-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Home Box 2', 'limelight' ),
		'id'            => 'home-box-2',
		'before_widget' => '<div class="home-box-inner">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="home-box-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Home Box 3', 'limelight' ),
		'id'            => 'home-box-3',
		'before_widget' => '<div class="home-box-inner">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="home-box-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'limelight_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function limelight_scripts() {
	wp_enqueue_style( 'limelight-style', get_stylesheet_uri() );
	wp_enqueue_style( 'limelight-fonts', 'http://fonts.googleapis.com/css?family=Open+Sans:400,300,700|Lobster');
	wp_enqueue_style( 'limelight-ie-only', get_template_directory_uri().'/css/ie.css' );
	global $wp_styles;
	$wp_styles->add_data( 'limelight-ie-only', 'conditional', 'lt IE 9' );
	wp_enqueue_script( 'limelight-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'limelight-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if(is_front_page()){
		wp_enqueue_script( 'responsive-slides', get_template_directory_uri() . '/js/responsiveslides.min.js', array('jquery'), '1.0', true );
	}

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'limelight_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Options Panel
 */
require get_template_directory() . '/inc/options-panel.php';